@@ -8,10 +8,9 @@ import (
 	"net/http"
 	"os"
 	"path/filepath"
+	"runtime"
 	"strings"
 
-	"github.com/AlecAivazis/survey/v2"
-	"github.com/AlecAivazis/survey/v2/terminal"
 	"github.com/containerd/containerd/identifiers"
 	"github.com/lima-vm/lima/cmd/limactl/editflags"
 	"github.com/lima-vm/lima/cmd/limactl/guessarg"
@@ -24,6 +23,8 @@ import (
 	"github.com/lima-vm/lima/pkg/store"
 	"github.com/lima-vm/lima/pkg/store/filenames"
 	"github.com/lima-vm/lima/pkg/templatestore"
+	"github.com/lima-vm/lima/pkg/uiutil"
+	"github.com/lima-vm/lima/pkg/version"
 	"github.com/lima-vm/lima/pkg/yqutil"
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
@@ -92,6 +93,9 @@ See the examples in 'limactl create --help'.
 		RunE:              startAction,
 	}
 	registerCreateFlags(startCommand, "[limactl create] ")
+	if runtime.GOOS != "windows" {
+		startCommand.Flags().Bool("foreground", false, "run the hostagent in the foreground")
+	}
 	startCommand.Flags().Duration("timeout", start.DefaultWatchHostAgentEventsTimeout, "duration to wait for the instance to be running before timing out")
 	return startCommand
 }
@@ -190,7 +194,7 @@ func loadOrCreateInstance(cmd *cobra.Command, args []string, createOnly bool) (*
 			return nil, errors.New("must pass instance name with --name when reading template from stdin")
 		}
 		st.yBytes, err = io.ReadAll(os.Stdin)
-		if err != nil && err != io.EOF {
+		if err != nil {
 			return nil, fmt.Errorf("unexpected error reading stdin: %w", err)
 		}
 		// see if the tty was set explicitly or not
@@ -323,7 +327,7 @@ func createInstance(ctx context.Context, st *creatorState, saveBrokenEditorBuffe
 		}
 		rejectedYAML := "lima.REJECTED.yaml"
 		if writeErr := os.WriteFile(rejectedYAML, st.yBytes, 0o644); writeErr != nil {
-			return nil, fmt.Errorf("the YAML is invalid, attempted to save the buffer as %q but failed: %v: %w", rejectedYAML, writeErr, err)
+			return nil, fmt.Errorf("the YAML is invalid, attempted to save the buffer as %q but failed: %w: %w", rejectedYAML, writeErr, err)
 		}
 		return nil, fmt.Errorf("the YAML is invalid, saved the buffer as %q: %w", rejectedYAML, err)
 	}
@@ -333,6 +337,9 @@ func createInstance(ctx context.Context, st *creatorState, saveBrokenEditorBuffe
 	if err := os.WriteFile(filePath, st.yBytes, 0o644); err != nil {
 		return nil, err
 	}
+	if err := os.WriteFile(filepath.Join(instDir, filenames.LimaVersion), []byte(version.Version), 0o444); err != nil {
+		return nil, err
+	}
 
 	inst, err := store.Inspect(st.instName)
 	if err != nil {
@@ -366,27 +373,25 @@ func chooseNextCreatorState(st *creatorState, yq string) (*creatorState, error)
 			logrus.WithError(err).Warn("Failed to evaluate yq expression")
 			return st, err
 		}
-		var ans string
-		prompt := &survey.Select{
-			Message: fmt.Sprintf("Creating an instance %q", st.instName),
-			Options: []string{
-				"Proceed with the current configuration",
-				"Open an editor to review or modify the current configuration",
-				"Choose another template (docker, podman, archlinux, fedora, ...)",
-				"Exit",
-			},
+		message := fmt.Sprintf("Creating an instance %q", st.instName)
+		options := []string{
+			"Proceed with the current configuration",
+			"Open an editor to review or modify the current configuration",
+			"Choose another template (docker, podman, archlinux, fedora, ...)",
+			"Exit",
 		}
-		if err := survey.AskOne(prompt, &ans); err != nil {
-			if err == terminal.InterruptErr {
+		ans, err := uiutil.Select(message, options)
+		if err != nil {
+			if errors.Is(err, uiutil.InterruptErr) {
 				logrus.Fatal("Interrupted by user")
 			}
 			logrus.WithError(err).Warn("Failed to open TUI")
 			return st, nil
 		}
 		switch ans {
-		case prompt.Options[0]: // "Proceed with the current configuration"
+		case 0: // "Proceed with the current configuration"
 			return st, nil
-		case prompt.Options[1]: // "Open an editor ..."
+		case 1: // "Open an editor ..."
 			hdr := fmt.Sprintf("# Review and modify the following configuration for Lima instance %q.\n", st.instName)
 			if st.instName == DefaultInstanceName {
 				hdr += "# - In most cases, you do not need to modify this file.\n"
@@ -405,20 +410,18 @@ func chooseNextCreatorState(st *creatorState, yq string) (*creatorState, error)
 				return st, errors.New("should not reach here")
 			}
 			return st, nil
-		case prompt.Options[2]: // "Choose another template..."
+		case 2: // "Choose another template..."
 			templates, err := templatestore.Templates()
 			if err != nil {
 				return st, err
 			}
-			var ansEx int
-			promptEx := &survey.Select{
-				Message: "Choose a template",
-				Options: make([]string, len(templates)),
-			}
+			message := "Choose a template"
+			options := make([]string, len(templates))
 			for i := range templates {
-				promptEx.Options[i] = templates[i].Name
+				options[i] = templates[i].Name
 			}
-			if err := survey.AskOne(promptEx, &ansEx); err != nil {
+			ansEx, err := uiutil.Select(message, options)
+			if err != nil {
 				return st, err
 			}
 			if ansEx > len(templates)-1 {
@@ -436,7 +439,7 @@ func chooseNextCreatorState(st *creatorState, yq string) (*creatorState, error)
 				return nil, err
 			}
 			continue
-		case prompt.Options[3]: // "Exit"
+		case 3: // "Exit"
 			os.Exit(0)
 			return st, errors.New("should not reach here")
 		default:
@@ -511,6 +514,14 @@ func startAction(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
+	launchHostAgentForeground := false
+	if runtime.GOOS != "windows" {
+		foreground, err := cmd.Flags().GetBool("foreground")
+		if err != nil {
+			return err
+		}
+		launchHostAgentForeground = foreground
+	}
 	timeout, err := cmd.Flags().GetDuration("timeout")
 	if err != nil {
 		return err
@@ -519,7 +530,7 @@ func startAction(cmd *cobra.Command, args []string) error {
 		ctx = start.WithWatchHostAgentTimeout(ctx, timeout)
 	}
 
-	return start.Start(ctx, inst)
+	return start.Start(ctx, inst, launchHostAgentForeground)
 }
 
 func createBashComplete(cmd *cobra.Command, _ []string, _ string) ([]string, cobra.ShellCompDirective) {
