@@ -9,7 +9,6 @@ import (
 	"fmt"
 	"net"
 	"net/http"
-	"strconv"
 
 	"github.com/lima-vm/lima/pkg/guestagent/api"
 	"github.com/lima-vm/lima/pkg/httpclientutil"
@@ -21,39 +20,13 @@ type GuestAgentClient interface {
 	Events(context.Context, func(api.Event)) error
 }
 
-type Proto = string
-
-const (
-	UNIX  Proto = "unix"
-	VSOCK Proto = "vsock"
-)
-
 // NewGuestAgentClient creates a client.
 // remote is a path to the UNIX socket, without unix:// prefix or a remote hostname/IP address.
-func NewGuestAgentClient(remote string, proto Proto, instanceName string) (GuestAgentClient, error) {
-	var hc *http.Client
-	switch proto {
-	case UNIX:
-		hcSock, err := httpclientutil.NewHTTPClientWithSocketPath(remote)
-		if err != nil {
-			return nil, err
-		}
-		hc = hcSock
-	case VSOCK:
-		_, p, err := net.SplitHostPort(remote)
-		if err != nil {
-			return nil, err
-		}
-		port, err := strconv.Atoi(p)
-		if err != nil {
-			return nil, err
-		}
-		hc, err = newVSockGuestAgentClient(port, instanceName)
-		if err != nil {
-			return nil, err
-		}
+func NewGuestAgentClient(conn net.Conn) (GuestAgentClient, error) {
+	hc, err := httpclientutil.NewHTTPClientWithConn(conn)
+	if err != nil {
+		return nil, err
 	}
-
 	return NewGuestAgentClientWithHTTPClient(hc), nil
 }
 
