@@ -9,20 +9,20 @@ import (
 	"path/filepath"
 	"runtime"
 	"strconv"
+	"strings"
 	"text/template"
 
 	"github.com/docker/go-units"
-	"github.com/lima-vm/lima/pkg/networks"
-	"github.com/lima-vm/lima/pkg/ptr"
 	"github.com/pbnjay/memory"
+	"github.com/sirupsen/logrus"
+	"golang.org/x/sys/cpu"
 
 	"github.com/lima-vm/lima/pkg/guestagent/api"
+	"github.com/lima-vm/lima/pkg/networks"
 	"github.com/lima-vm/lima/pkg/osutil"
+	"github.com/lima-vm/lima/pkg/ptr"
 	"github.com/lima-vm/lima/pkg/store/dirnames"
 	"github.com/lima-vm/lima/pkg/store/filenames"
-	"github.com/sirupsen/logrus"
-
-	"golang.org/x/sys/cpu"
 )
 
 const (
@@ -83,6 +83,26 @@ func MACAddress(uniqueID string) string {
 	return hw.String()
 }
 
+func hostTimeZone() string {
+	// WSL2 will automatically set the timezone
+	if runtime.GOOS != "windows" {
+		tz, err := os.ReadFile("/etc/timezone")
+		if err == nil {
+			return strings.TrimSpace(string(tz))
+		}
+		zoneinfoFile, err := filepath.EvalSymlinks("/etc/localtime")
+		if err == nil {
+			for baseDir := filepath.Dir(zoneinfoFile); baseDir != "/"; baseDir = filepath.Dir(baseDir) {
+				if _, err = os.Stat(filepath.Join(baseDir, "Etc/UTC")); err == nil {
+					return strings.TrimPrefix(zoneinfoFile, baseDir+"/")
+				}
+			}
+			logrus.Warnf("could not locate zoneinfo directory from %q", zoneinfoFile)
+		}
+	}
+	return ""
+}
+
 func defaultCPUs() int {
 	const x = 4
 	if hostCPUs := runtime.NumCPU(); hostCPUs < x {
@@ -325,6 +345,16 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 		}
 	}
 
+	if y.TimeZone == nil {
+		y.TimeZone = d.TimeZone
+	}
+	if o.TimeZone != nil {
+		y.TimeZone = o.TimeZone
+	}
+	if y.TimeZone == nil {
+		y.TimeZone = ptr.Of(hostTimeZone())
+	}
+
 	if y.SSH.LocalPort == nil {
 		y.SSH.LocalPort = d.SSH.LocalPort
 	}
@@ -397,6 +427,11 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 		if provision.Mode == ProvisionModeDependency && provision.SkipDefaultDependencyResolution == nil {
 			provision.SkipDefaultDependencyResolution = ptr.Of(false)
 		}
+		if out, err := executeGuestTemplate(provision.Script); err == nil {
+			provision.Script = out.String()
+		} else {
+			logrus.WithError(err).Warnf("Couldn't process provisioning script %q as a template", provision.Script)
+		}
 	}
 
 	if y.GuestInstallPrefix == nil {
@@ -409,6 +444,16 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 		y.GuestInstallPrefix = ptr.Of(defaultGuestInstallPrefix())
 	}
 
+	if y.UpgradePackages == nil {
+		y.UpgradePackages = d.UpgradePackages
+	}
+	if o.UpgradePackages != nil {
+		y.UpgradePackages = o.UpgradePackages
+	}
+	if y.UpgradePackages == nil {
+		y.UpgradePackages = ptr.Of(false)
+	}
+
 	if y.Containerd.System == nil {
 		y.Containerd.System = d.Containerd.System
 	}
@@ -731,6 +776,7 @@ func fixUpForPlainMode(y *LimaYAML) {
 	y.Containerd.User = ptr.Of(false)
 	y.Rosetta.BinFmt = ptr.Of(false)
 	y.Rosetta.Enabled = ptr.Of(false)
+	y.TimeZone = ptr.Of("")
 }
 
 func executeGuestTemplate(format string) (bytes.Buffer, error) {
@@ -764,7 +810,7 @@ func executeHostTemplate(format, instDir string) (bytes.Buffer, error) {
 			"User": user.Username,
 
 			"Instance": filepath.Base(instDir), // DEPRECATED, use `{{.Name}}`
-			"LimaHome": limaHome,               // DEPRECATED, (use `Dir` instead of `{{.LimaHome}}/{{.Instance}}`
+			"LimaHome": limaHome,               // DEPRECATED, use `{{.Dir}}` instead of `{{.LimaHome}}/{{.Instance}}`
 		}
 		var out bytes.Buffer
 		if err := tmpl.Execute(&out, data); err == nil {
