@@ -3,6 +3,7 @@ package osutil
 import (
 	"fmt"
 	"io/fs"
+	"os"
 	"syscall"
 
 	"golang.org/x/sys/windows"
@@ -33,6 +34,21 @@ func SysKill(pid int, _ Signal) error {
 	return windows.GenerateConsoleCtrlEvent(syscall.CTRL_BREAK_EVENT, uint32(pid))
 }
 
+func Dup2(oldfd int, newfd syscall.Handle) (err error) {
+	return fmt.Errorf("unimplemented")
+}
+
 func Ftruncate(_ int, _ int64) (err error) {
 	return fmt.Errorf("unimplemented")
 }
+
+func SignalName(sig os.Signal) string {
+	switch sig {
+	case syscall.SIGINT:
+		return "SIGINT"
+	case syscall.SIGTERM:
+		return "SIGTERM"
+	default:
+		return fmt.Sprintf("Signal(%d)", sig)
+	}
+}
