@@ -618,8 +618,15 @@ func Cmdline(cfg Config) (exe string, args []string, err error) {
 			}
 
 			if disk.Instance != "" {
-				logrus.Errorf("could not attach disk %q, in use by instance %q", diskName, disk.Instance)
-				return "", nil, err
+				if disk.InstanceDir != cfg.InstanceDir {
+					logrus.Errorf("could not attach disk %q, in use by instance %q", diskName, disk.Instance)
+					return "", nil, err
+				}
+				err = disk.Unlock()
+				if err != nil {
+					logrus.Errorf("could not unlock disk %q to reuse in the same instance %q", diskName, cfg.Name)
+					return "", nil, err
+				}
 			}
 			logrus.Infof("Mounting disk %q on %q", diskName, disk.MountPoint)
 			err = disk.Lock(cfg.InstanceDir)
@@ -1129,6 +1136,7 @@ func getFirmware(qemuExe string, arch limayaml.Arch) (string, error) {
 	case limayaml.X8664:
 		// Debian package "ovmf"
 		candidates = append(candidates, "/usr/share/OVMF/OVMF_CODE.fd")
+		candidates = append(candidates, "/usr/share/OVMF/OVMF_CODE_4M.fd")
 		// openSUSE package "qemu-ovmf-x86_64"
 		candidates = append(candidates, "/usr/share/qemu/ovmf-x86_64-code.bin")
 		// Archlinux package "edk2-ovmf"
