@@ -325,7 +325,7 @@ func (l *LimaQemuDriver) shutdownQEMU(ctx context.Context, timeout time.Duration
 	select {
 	case qWaitErr := <-qWaitCh:
 		logrus.WithError(qWaitErr).Info("QEMU has exited")
-		l.removeVNCFiles()
+		_ = l.removeVNCFiles()
 		return errors.Join(qWaitErr, l.killVhosts())
 	case <-deadline:
 	}
@@ -346,7 +346,7 @@ func (l *LimaQemuDriver) killQEMU(_ context.Context, _ time.Duration, qCmd *exec
 	}
 	qemuPIDPath := filepath.Join(l.Instance.Dir, filenames.PIDFile(*l.Yaml.VMType))
 	_ = os.RemoveAll(qemuPIDPath)
-	l.removeVNCFiles()
+	_ = l.removeVNCFiles()
 	return errors.Join(qWaitErr, l.killVhosts())
 }
 
@@ -394,6 +394,12 @@ func (l *LimaQemuDriver) ListSnapshots(_ context.Context) (string, error) {
 	return List(qCfg, l.Instance.Status == store.StatusRunning)
 }
 
+func (l *LimaQemuDriver) GuestAgentConn(ctx context.Context) (net.Conn, error) {
+	var d net.Dialer
+	dialContext, err := d.DialContext(ctx, "unix", filepath.Join(l.Instance.Dir, filenames.GuestAgentSock))
+	return dialContext, err
+}
+
 type qArgTemplateApplier struct {
 	files []*os.File
 }
