@@ -48,6 +48,7 @@ var knownYamlProperties = []string{
 	"Provision",
 	"Rosetta",
 	"SSH",
+	"TimeZone",
 	"Video",
 	"VMType",
 }
@@ -155,7 +156,7 @@ func (l *LimaVzDriver) Start(ctx context.Context) (chan error, error) {
 	vm, errCh, err := startVM(ctx, l.BaseDriver)
 	if err != nil {
 		if errors.Is(err, vz.ErrUnsupportedOSVersion) {
-			return nil, fmt.Errorf("vz driver requires macOS 13 or higher to run: %q", err)
+			return nil, fmt.Errorf("vz driver requires macOS 13 or higher to run: %w", err)
 		}
 		return nil, err
 	}
@@ -177,7 +178,7 @@ func (l *LimaVzDriver) RunGUI() error {
 	if l.CanRunGUI() {
 		return l.machine.StartGraphicApplication(1920, 1200)
 	}
-	return fmt.Errorf("RunGUI is not support for the given driver '%s' and diplay '%s'", "vz", *l.Yaml.Video.Display)
+	return fmt.Errorf("RunGUI is not supported for the given driver '%s' and display '%s'", "vz", *l.Yaml.Video.Display)
 }
 
 func (l *LimaVzDriver) Stop(_ context.Context) error {
